import { computed } from 'vue'
import { t } from '@/plugins/i18n'
import type { Ref } from 'vue'
import type { Password } from '#/user'

export function useRules(passwords?: Ref<Password>) {
  const requiredField = computed(() => (
      [(val: any) => (!!val && val.trim().length > 0) || t('form.rule.required')]
  ))
  const passwordField = computed(() => {
    return [
      ...requiredField.value,
      (pass: string) => (pass && pass.length > 7) || t('form.rule.minPassLength')
    ]
  })
  if (!passwords) {
    return {
      requiredField,
      passwordField
    }
  }
  else {
    const passwordMatch = computed(() => {
      return [
        ...passwordField.value,
        (pass: string) => pass === passwords.value.newPassword || t('form.rule.passMatch')
      ]
    })
    return {
      passwordField,
      passwordMatch,
      requiredField,
    }
  }


}
