import type { RouteLocationRaw } from 'vue-router';

type CssClassesObject = Record<string, boolean>;
export type CssClasses = CssClassesObject | string;

interface SubtitleObject {
  label: string;
  value: string;
}
export interface SubtitleLink {
  label?: string;
  value: string;
  to: RouteLocationRaw;
}
export type Subtitles = (string | SubtitleObject | SubtitleLink)[];

export interface CrudActionButton {
  icon?: string;
  to?: RouteLocationRaw;
  href?: string;
  tooltip: string;
}

export type CrudItemAction =
  | 'promote-manager'
  | 'dismiss-manager'
  | 'remove-member'
  | 'edit-group'
  | 'remove-group'
  | 'edit-referential'
  | 'remove-referential'
  | 'view-referential'
  | 'bind-referential'
  | 'unbind-referential'
  | 'remove-referential';

export interface CrudItemActionButton {
  disabled?: boolean;
  name: CrudItemAction;
  icon: string;
  tooltip: string;
}

export interface CrudItem {
  id: string;
  thumbnail?: string;
  name: string;
  isPublic?: boolean;
  subtitles?: string[];
  createdAt?: string;
  updatedAt?: string;
  isSelectable?: boolean;
  to?: RouteLocationRaw;
  status?: CrudStatus;
  actions?: CrudItemActionButton[];
}

export interface CrudStatus {
  label: string;
}

export interface CrudAction {
  name: string;
  icon: string;
  disabled: boolean;
}

export interface CrudTitle {
  label: string;
  tag?: 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6';
  classes: CssClasses;
}

export type PaginationObject = {
  /** Column name (from column definition) */
  sortBy?: string;
  /** Is sorting in descending order? */
  descending?: boolean;
  /** Page number (1-based) */
  page: number;
  /** How many rows per page? 0 means Infinite */
  rowsPerPage: number;
  /**
   * For server-side fetching only.
   * How many total database rows are there to be added to the table.
   */
  rowsNumber?: number;
};

type NonPaginatedGetFunction = () => void;
export type GetFunction = NonPaginatedGetFunction | PaginatedGetFunction;
